===================================
Welcome to datapkg's documentation!
===================================

datapkg is a tool for distributing, discovering and installing knowledge
(data and content) 'packages'.

datapkg is a *simple* way to 'package' data building on *existing* packaging
tools developed for code. datapkg is designed to integrate closely with the
`CKAN (Comprehensive Knowledge Archive Network) <http://www.ckan.net/>`_.

By putting data in a package, it gets labelled with standardized metadata and
can be put in a datapkg repository, such as CKAN or a local one. Once in such
a repository, the packages are easy to find and retrieve.

Users
=====

We recommend users get started by taking a look at the manual (if you haven't
installed datapkg yet see the installation instructions below):

.. toctree::

   manual

Developers
==========

For developers we recommend starting with the design overview:

.. toctree::

   design

There are also a set of use cases and details of the API.

.. toctree::

   usecases
   api

Other material
==============

.. toctree::

   install
   license
   CHANGELOG
   external

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

